pub struct SigningResponse {
pub signers_count: usize,
pub signers_consulted: usize,
pub prevented_index: Option<usize>,
pub defer_count: usize,
pub signed_index: Option<usize>,
pub output: Option<SignedOutput>,
}Expand description
Represents the execution results of a signing event.
Fields
signers_count: usizeTotal number of Signer that exist.
signers_consulted: usizeTotal number of Signer that were consulted for this event.
Consultation stops once a Signer handles the event or instructs processing to stop.
prevented_index: Option<usize>Index of Signer that prevented signing.
defer_count: usizeNumber of signers that deferred to process this request.
signed_index: Option<usize>Index of the Signer that signed this response.
output: Option<SignedOutput>The output of a successful code signing operation.